Identify all application components
-------

**Description:**

When you are building an application you first want to map where you are placing 
source files, libraries and executables.

With these components identified and mapped, it becomes transparant where possible 
pitfalls might be in your application and increases the maintainability of the 
system. Also you have an indicator where possible reinforcements have to be
implemented to avoid attacks.(i.e places where your application contains executable's)

**Solution:**

Verify that all application components (either individual or groups of source files, 
libraries, and/or executables) that are present in the application are identified.

When you identified these components you may want to map and document them in order to
have a quick reference to this infrastructure when needed.
 



   
